AppbundleCommand class

Android App Bundle build command implementation.

Builds Android App Bundle (AAB) files optimized for Google Play Store distribution with dynamic delivery support and size optimizations.

Platform Requirements

  • Android SDK and tools
  • Flutter SDK with Android support
  • Valid Android project configuration
  • Android Gradle Plugin 3.2+ for App Bundle support

App Bundle Benefits

  • Smaller download sizes through dynamic delivery
  • Automatic APK generation by Google Play
  • Enhanced security and optimization
  • Support for feature modules and asset packs

Usage Examples

# Build release App Bundle for production
morpheme build appbundle --flavor prod --release

# Build with custom signing configuration
morpheme build appbundle --flavor staging --build-number 42
Inheritance

Constructors

AppbundleCommand()

Properties

aliases → List<String>
Alternate names for this command.
no setterinherited
argParser → ArgParser
The argument parser for this command.
no setterinherited
argResults → ArgResults?
The parsed argument results for this command.
no setterinherited
buildTarget → String
The target platform for this build command (e.g., 'apk', 'appbundle', 'ios').
no setteroverride
category → String
The command's category.
no setterinherited
description → String
A description of this command, included in usage.
no setteroverride
globalResults → ArgResults?
The parsed global argument results.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
Whether or not this command should be hidden from help listings.
no setterinherited
invocation → String
A single-line template for how to invoke this command (e.g. "pub get package").
no setterinherited
name → String
The name of this command.
no setteroverride
parent → Command?
The command's parent command, if this is a subcommand.
no setterinherited
runner → CommandRunner?
The command runner for this command.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subcommands → Map<String, Command>
An unmodifiable view of all sublevel commands of this command.
no setterinherited
suggestionAliases → List<String>
Alternate non-functional names for this command.
no setterinherited
summary → String
A short description of this command, included in parent's CommandRunner.usage.
no setterinherited
takesArguments → bool
Whether or not this command takes positional arguments in addition to options.
no setterinherited
usage → String
Generates a string displaying usage information for this command.
no setterinherited
usageFooter → String?
An optional footer for usage.
no setterinherited

Methods

addSubcommand(Command command) → void
Adds Command as a subcommand of this.
inherited
constructBuildCommand(List<String> dartDefines) → String
Constructs the build command string.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printUsage() → void
Prints the usage information for this command.
inherited
run() → void
Runs this command.
inherited
toString() → String
A string representation of this object.
inherited
usageException(String message) → Never
Throws a UsageException with message.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited