FindProgress class

Progress tracker for find operations.

This class manages the execution and results of file system searches, providing both streaming and batch processing capabilities.

Example:

final progress = find('*.dart');
progress.forEach(print); // Process each result

final files = progress.toList(); // Get all results as list
final first = progress.firstLine; // Get first result only
Inheritance

Constructors

FindProgress(String pattern, {required bool caseSensitive, required bool recursion, required bool includeHidden, required String workingDirectory, required List<FileSystemEntityType> types})
Create a new find progress tracker.

Properties

caseSensitive ↔ bool
If true then we do a case sensitive match on filenames.
getter/setter pair
firstLine → String?
Returns the first line from the command or null if no lines where returned
no setter
hashCode → int
The hash code for this object.
no setterinherited
includeHidden ↔ bool
include hidden files and directories in the search
getter/setter pair
pattern ↔ String
The glob pattern we are searching for matches on
getter/setter pair
recursion ↔ bool
recurse into subdirectories
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
types ↔ List<FileSystemEntityType>
The list of file system entity types to search file.
getter/setter pair
workingDirectory ↔ String
The directory to start searching from and below (if recursion is true)
getter/setter pair

Methods

forEach(LineAction action) → void
If you need to perform async operations you should use core.find.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toList() → List<String>
Convert all results to a list.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited