ArgResults class

The results of parsing a series of command line arguments using ArgParser.parse.

Includes the parsed options and any remaining unparsed command line arguments.

Available extensions

Properties

arguments → List<String>
The original arguments that were parsed.
final
command → ArgResults?
The command that was selected, or null if none was.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the command for which these options are parsed, or null if these are the top-level results.
final
options → Iterable<String>
The names of the available options.
no setter
rest → List<String>
The remaining command-line arguments that were not parsed as options or flags.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

flag(String name) → bool
Returns the parsed or default command-line flag named name.
getDeviceId() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the device ID option formatted for command-line usage.
getFlagCodesign() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the codesign flag value formatted for command-line usage.
getFlagCsp() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the CSP flag value formatted for command-line usage.
getFlagDebug() → bool

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the debug flag value.
getFlagDumpInfo() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the dump info flag value formatted for command-line usage.
getFlagFrequencyBasedMinification() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the frequency based minification flag value formatted for command-line usage.
getFlagGenerateL10n() → bool

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the generate l10n flag value.
getFlagObfuscate() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the obfuscate flag value formatted for command-line usage.
getFlagObfuscateBool() → bool

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the obfuscate flag value as a boolean.
getFlagProfile() → bool

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the profile flag value.
getFlagRelease() → bool

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the release flag value.
getFlagSourceMaps() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the source maps flag value formatted for command-line usage.
getFlagWebResourcesCdn() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the web resources CDN flag value formatted for command-line usage.
getMode() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the build mode as a command-line flag.
getOptionBaseHref() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the base href option formatted for command-line usage.
getOptionBuildName() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the build name option formatted for command-line usage.
getOptionBuildNumber() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the build number option formatted for command-line usage.
getOptionDart2JsOptimization() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the dart2js optimization option formatted for command-line usage.
getOptionExportMethod() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the export method option formatted for command-line usage.
getOptionExportOptionsPlist() → String?

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the export options plist option formatted for command-line usage.
getOptionFlavor({required String defaultTo}) → String

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the flavor option value.
getOptionMorphemeYaml() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the custom path to morpheme.yaml.
getOptionPwaStrategy() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the PWA strategy option formatted for command-line usage.
getOptionSplitDebugInfo() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the split debug info option formatted for command-line usage.
getOptionTarget() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the target file path.
getOptionWebRenderer() → String

Available on ArgResults?, provided by the ArgResultsExtension extension

Gets the web renderer option formatted for command-line usage.
multiOption(String name) → List<String>
Returns the list of parsed (or default) command-line options for name.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
option(String name) → String?
Returns the parsed or default command-line option named name.
toString() → String
A string representation of this object.
inherited
wasParsed(String name) → bool
Returns true if the option with name was parsed from an actual argument.

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String name) → dynamic
Returns the parsed or default command-line option named name.