AppsController class

Controller for coordinating app module creation operations.

This class orchestrates the creation of new app modules by coordinating between various managers and generators.

Constructors

AppsController()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createApp(String rawAppName) → Future<void>
Creates a new app module with all required files and configurations.