LocatorManager class

Manages locator.dart file modifications for app modules.

This class handles updating the main locator.dart file to register the new app module's locator setup function.

Constructors

LocatorManager()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

addNewAppsInLocator(String pathApps, String appsName) → void
Adds a new app module to the main locator.dart file.