ConfigurationException class

Exception thrown when configuration loading or validation fails.

Implemented types

Constructors

ConfigurationException(String message, {List<String> suggestions = const []})
Creates a new ConfigurationException.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
The primary error message.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suggestions → List<String>
List of suggestions for resolving the configuration issue.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited