ValidationWarning class

Represents a validation warning that doesn't prevent operation.

Constructors

ValidationWarning({required String message, String? field, required ValidationWarningType type})
Creates a new ValidationWarning instance.
const

Properties

field → String?
The field or property that triggered the warning (optional).
final
hashCode → int
The hash code for this object.
no setteroverride
message → String
The warning message describing the potential issue.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ValidationWarningType
The type of validation warning.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override