FileSystemException class

Exception thrown when file system operations fail.

Implemented types

Constructors

FileSystemException(String message, [Object? cause])
Creates a new FileSystemException.
const

Properties

cause → Object?
Optional underlying cause of the exception.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
The error message describing what went wrong.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited