EndpointConfig class

Configuration model for endpoint generation.

This class encapsulates all the parameters needed for generating endpoint files.

Constructors

EndpointConfig({required String projectName, required String outputPath, required List<String> json2DartPaths})
Creates a new EndpointConfig instance.

Properties

hashCode → int
The hash code for this object.
no setterinherited
json2DartPaths → List<String>
List of paths to json2dart.yaml files.
final
outputPath → String
The path where the endpoint file will be generated.
final
projectName → String
The project name used for generating endpoint class name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited