FeatureConfig class

Configuration model for feature generation.

This class encapsulates all the parameters needed for generating a new feature module.

Constructors

FeatureConfig({required String featureName, required String appsName, required String featurePath, required String appsPath, required bool isInApps})
Creates a new FeatureConfig instance.

Properties

appsName → String
The name of the apps module (if applicable).
final
appsPath → String
The path to the apps module (if applicable).
final
featureName → String
The name of the feature being created.
final
featurePath → String
The path where the feature will be created.
final
hashCode → int
The hash code for this object.
no setterinherited
isInApps → bool
Indicates if the feature is within an apps module.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited