FirebaseConfig class

Data model for Firebase configuration parameters.

This class encapsulates all Firebase configuration parameters needed for the Firebase generation process.

Constructors

FirebaseConfig({required String projectId, String? token, String? platform, String? output, required String androidPackageName, required String iosBundleId, String? webAppId, String? serviceAccount, bool enableCiUseServiceAccount = false, bool overwrite = false})
Creates a new FirebaseConfig instance.
FirebaseConfig.fromMap(Map map, Map flavor)
Creates a FirebaseConfig from a map of configuration values.
factory

Properties

androidPackageName → String
Android application package name
final
enableCiUseServiceAccount → bool
Flag to enable service account in CI/CD
final
hashCode → int
The hash code for this object.
no setterinherited
iosBundleId → String
iOS bundle identifier
final
output → String?
Output path for firebase_options.dart
final
overwrite → bool
Flag to force overwrite existing configuration
final
platform → String?
Target platforms for configuration
final
projectId → String
Firebase project ID
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount → String?
Path to service account JSON file
final
token → String?
Optional authentication token
final
webAppId → String?
Web application ID
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited