EntityGenerator class

Generates Dart entity classes for domain layer

This generator creates domain entities with immutable properties and copyWith methods for state management.

Inheritance

Constructors

EntityGenerator()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateClass(String suffix, String name, String parent, Map<String, dynamic>? map, [bool isRoot = false]) → String
Generates class content from a map structure
override
generateConstructor(String className, Map<String, dynamic> map, [bool isMultipart = false, List<String> paramPath = const []]) → String
Generates constructor parameters
inherited
generateEntity(String className, Map<String, dynamic> data) → String
Generates a complete entity file
generateProps(Map<String, dynamic> map, [bool isMultipart = false, List<String> paramPath = const [], String rawVariable = '']) → String
Generates Equatable props
inherited
getTypeExtraVariable(String key, dynamic value, String suffix, List<ModelClassName> listClassName, String parent) → String
Gets the appropriate type for a given value
inherited
getTypeVariable(String key, dynamic value, String suffix, List<ModelClassName> listClassName, String parent) → String
Gets the appropriate type for a given value
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited