DatabaseTemplate class

Template for database instance code generation.

This class provides static methods for generating the database instance class code with proper formatting and structure.

Constructors

DatabaseTemplate()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

generate({required String dirDatabase, required bool foreignKeyConstrainSupport, required int version, required String tableCreationSql, required String viewCreationSql, required String triggerCreationSql, required String seedSql}) → String
Generates the database instance class.