PathHelper class abstract

Helper class for path construction in remove commands.

Constructors

PathHelper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getAppsPath(String appsName) → String
Gets the path for an app directory.
getAppsTestPath(String appsName) → String
Gets the path for an app test directory.
getFeaturePath(String appsName, String featureName) → String
Gets the path for a feature directory.
getFeatureTestPath(String appsName, String featureName) → String
Gets the path for a feature test directory.
getPagePath(String appsName, String featureName, String pageName) → String
Gets the path for a page directory.
getPageTestPath(String appsName, String featureName, String pageName) → String
Gets the path for a page test directory.