FlutterHelper class abstract

Constructors

FlutterHelper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getCommandDart() → String
Gets the appropriate Dart command for the current platform.
getCommandFlutter() → String
Gets the appropriate Flutter command for the current platform.
run(String argument, {bool showLog = false}) → Future<int>
Runs a Flutter command and waits for completion.
start(String argument, {bool showLog = false, String? workingDirectory, void progressOut(String line)?, void progressErr(String line)?}) → Future<int>
Starts a Flutter process and returns immediately.
startWithStdin(String argument, {bool showLog = false, bool singleCharacterMode = false, String? workingDirectory, void progressOut(String line)?, void progressErr(String line)?}) → Future<int>
Starts a Flutter process with stdin forwarding for interactive commands.