HttpClientHelper class

Helper class for HTTP client operations.

This class provides utilities for downloading files over HTTP with progress reporting capabilities.

Constructors

HttpClientHelper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

downloadFile(String url, {dynamic onProgress(int downloadedLength, int contentLength, double progress)?}) → Future<List<int>>
Downloads a file from a URL with optional progress reporting.