ReCase class

An instance of text to be re-cased.

This class takes a string and provides getters for various naming conventions, making it easy to convert between different text cases.

Constructors

ReCase(String text)
Creates a new ReCase instance with the provided text.

Properties

camelCase → String
Gets the text in camelCase format.
no setter
constantCase → String
Gets the text in CONSTANT_CASE format.
no setter
dotCase → String
Gets the text in dot.case format.
no setter
hashCode → int
The hash code for this object.
no setterinherited
headerCase → String
Gets the text in Header-Case format.
no setter
originalText ↔ String
The original text provided to the ReCase instance
getter/setter pair
paramCase → String
Gets the text in param-case format.
no setter
pascalCase → String
Gets the text in PascalCase format.
no setter
pathCase → String
Gets the text in path/case format.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sentenceCase → String
Gets the text in Sentence case format.
no setter
snakeCase → String
Gets the text in snake_case format.
no setter
symbolSet → Set<String>
final
titleCase → String
Gets the text in Title Case format.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited