StringReCase extension

Extension methods for String to provide easy access to ReCase functionality.

This extension adds getters to the String class for convenient case conversion without having to create a ReCase instance directly.

on

Properties

camelCase → String

Available on String, provided by the StringReCase extension

Gets the text in camelCase format.
no setter
constantCase → String

Available on String, provided by the StringReCase extension

Gets the text in CONSTANT_CASE format.
no setter
dotCase → String

Available on String, provided by the StringReCase extension

Gets the text in dot.case format.
no setter
headerCase → String

Available on String, provided by the StringReCase extension

Gets the text in Header-Case format.
no setter
paramCase → String

Available on String, provided by the StringReCase extension

Gets the text in param-case format.
no setter
pascalCase → String

Available on String, provided by the StringReCase extension

Gets the text in PascalCase format.
no setter
pathCase → String

Available on String, provided by the StringReCase extension

Gets the text in path/case format.
no setter
sentenceCase → String

Available on String, provided by the StringReCase extension

Gets the text in Sentence case format.
no setter
snakeCase → String

Available on String, provided by the StringReCase extension

Gets the text in snake_case format.
no setter
titleCase → String

Available on String, provided by the StringReCase extension

Gets the text in Title Case format.
no setter