ExclusionConfiguration class

Configuration class for exclusion patterns during refactoring.

Constructors

ExclusionConfiguration({required List<String> excludeChanges, required List<String> excludeFiles, required List<String> excludeDirectories})
const

Properties

excludeChanges → List<String>
List of code patterns to exclude from renaming operations
final
excludeDirectories → List<String>
List of directories to completely exclude from refactoring
final
excludeFiles → List<String>
List of specific file paths to exclude from changes
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited