CoverageConfiguration class

Configuration class for coverage command parameters.

Constructors

CoverageConfiguration({String? apps, String? feature, String? page, String? reporter, String? fileReporter})
const

Properties

apps → String?
final
feature → String?
final
fileReporter → String?
final
hashCode → int
The hash code for this object.
no setterinherited
page → String?
final
reporter → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited