ShorebirdCommandNames class

Command name constants for Shorebird commands.

This class contains all the command names used throughout the Shorebird CLI module to ensure consistency and avoid magic strings.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

android → const String
apk → const String
appbundle → const String
ios → const String
ipa → const String
patch → const String
Patch command names
release → const String
Release command names
shorebird → const String
The main shorebird command name