patch constant
String
const patch
Patch command descriptions
Implementation
static const String patch =
'Creates a shorebird patch for the provided target platforms';
Patch command descriptions
static const String patch =
'Creates a shorebird patch for the provided target platforms';