ToolCheck class

Configuration for a tool check.

Constructors

ToolCheck({required String name, required String displayName, required String usage, required bool isRequired, String? installCommand, String? installUrl})
const

Properties

displayName → String
The human-readable name of the tool
final
hashCode → int
The hash code for this object.
no setterinherited
installCommand → String?
Command to install the tool (if available)
final
installUrl → String?
URL with installation instructions
final
isRequired → bool
Whether this tool is required for basic Morpheme CLI functionality
final
name → String
The command name used to check if the tool is installed
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usage → String
Description of what the tool is used for
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited