RenameOptions class

Configuration options for the rename operation.

Constructors

RenameOptions({required String prefix, required String suffix, required String globPattern, required String workingDirectory, required bool isDryRun, required bool verbose})
const

Properties

globPattern → String
Glob pattern to match files
final
hashCode → int
The hash code for this object.
no setterinherited
isDryRun → bool
Whether this is a dry run (preview only)
final
prefix → String
Prefix to add to filenames
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suffix → String
Suffix to add to filenames
final
verbose → bool
Whether to show verbose output
final
workingDirectory → String
Directory to search for files
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited